@@ -1,10 +1,12 @@
-if( !exists("unitTestPath")) unitTestPath <- "."
+if( !exists("unitTestPath")) unitTestPath <- system.file(package = "MSToolkit", "Runit")
 parameters.datapath <- file.path( unitTestPath , "data", "createParameters" )
 covariates.datapath <- file.path( unitTestPath , "data", "createCovariates" )
 
 test.data.param.ext <- function(){
- 
+
   testParamFile <- "testParam.csv"
+  otherFiles <- paste("testParam", c("nonmem", "spaceDelim", "tabDelim"), sep=".")
+
   wrongTestParamFile <- "wrongTestParam.csv"
   
   # test the inputs  
@@ -59,58 +61,71 @@ test.data.param.ext <- function(){
       file = testParamFile, workingPath = parameters.datapath, errStruc = "w" ), 
     msg = "wrong errStruc" )
 
-  dataNone <- createExternalParameters( 20, names = "E0,ED50", dataId="ID",
-    file = testParamFile, workingPath = parameters.datapath, 
-    errStruc = "n", betNames = "B1,B2", seed = 2 )
+  # Basic check: different delimiters
+	dataNone <- createExternalParameters( 20, names = "E0,ED50", dataId="ID",
+		file = testParamFile, workingPath = parameters.datapath, 
+		errStruc = "None", betNames = "B1,B2", seed = 2 )
+	for (i in otherFiles) {
+		newData <- createExternalParameters( 20, names = "E0,ED50", dataId="ID",
+				file = i, workingPath = parameters.datapath, 
+				errStruc = "None", betNames = "B1,B2", seed = 2 )
+	
+		checkTrue(all(dim(dataNone) == dim(newData)), msg = paste("Check correct dimensions when importing", i))
+		checkTrue(all(names(dataNone) == names(newData)), msg = paste("Check correct column names when importing", i))
+		checkTrue(all(round(dataNone$ED50, 3) == newData$ED50), msg = paste("Check correct ED50 column when importing", i))
+		checkTrue(all(round(dataNone$B1, 3) == newData$B1), msg = paste("Check correct B1 column when importing", i))
+	}
+
+
+  # Basic working
   dataAdd  <- createExternalParameters( 20, names = "E0,ED50", dataId="ID",
     file = testParamFile, workingPath = parameters.datapath, 
-    errStruc = "a", betNames = "B1,B2", seed = 2 )
-  dataProp  <- createExternalParameters( 20, names = "E0,ED50", dataId="ID",
+    errStruc = "Add", betNames = "B1,B2", seed = 2 )
+  dataLogNorm <- createExternalParameters( 20, names = "E0,ED50", dataId="ID",
     file = testParamFile, workingPath = parameters.datapath, 
-    errStruc = "p", betNames = "B1,B2", seed = 2 )
-  checkTrue( identical( dataNone$E0   + dataNone$B1, dataAdd$E0  ), 
-    msg = "Testing the Additive errStruc" )
-  checkTrue( identical( dataNone$ED50 + dataNone$B2, dataAdd$ED50), 
-    msg = "Testing the Additive errStruc")
-  checkTrue( identical( exp(dataNone$E0   + dataNone$B1), dataProp$E0  ), 
-    msg = "Testing the Proportional errStruc" )
-  checkTrue( identical( exp(dataNone$ED50 + dataNone$B2), dataProp$ED50), 
-    msg = "Testing the Proportional errStruc")
- 
+    errStruc = "Log", betNames = "B1,B2", seed = 2 )
+  dataProp <- createExternalParameters( 20, names = "E0,ED50", dataId="ID",
+		file = testParamFile, workingPath = parameters.datapath, 
+		errStruc = "Pro", betNames = "B1,B2", seed = 2 )
+
+  checkTrue( identical( dataNone$E0   + dataNone$B1, dataAdd$E0  ),  msg = "Testing the Additive errStruc" )
+  checkTrue( identical( dataNone$ED50 + dataNone$B2, dataAdd$ED50),  msg = "Testing the Additive errStruc")
+  checkTrue( identical( dataNone$E0 * exp(dataNone$B1), dataLogNorm$E0  ), msg = "Testing the Log-Normal errStruc" )
+  checkTrue( identical( dataNone$ED50 * exp(dataNone$B2), dataLogNorm$ED50), msg = "Testing the Log-Normal errStruc")
+  checkTrue( identical( dataNone$E0 * (1 + dataNone$B1), dataProp$E0  ), msg = "Testing the Proportional errStruc" )
+  checkTrue( identical( dataNone$ED50 * (1 + dataNone$B2), dataProp$ED50), msg = "Testing the Proportional errStruc")
     
   dataNone <- createExternalParameters( 20, names = "E0,ED50", dataId="ID",
     file = testParamFile, workingPath = parameters.datapath, 
-    errStruc = "n", betNames = "B1,B2", seed = 2 )
+    errStruc = "N", betNames = "B1,B2", seed = 2 )
   dataAdd  <- createExternalParameters( 20, names = "E0,ED50", dataId="ID",
     file = testParamFile, workingPath = parameters.datapath, 
-    errStruc = "a", betNames = "B1,B2", betNums = "2,1", seed = 2 )
-  checkTrue( identical( dataNone$E0   + dataNone$B2, dataAdd$E0  ), 
-    msg = "Testing the Additive errStruc and betNums" )
-  checkTrue( identical( dataNone$ED50 + dataNone$B1, dataAdd$ED50), 
-    msg = "Testing the Additive errStruc and betNums")
+    errStruc = "A", betNames = "B1,B2", betNums = "2,1", seed = 2 )
+  checkTrue( identical( dataNone$E0   + dataNone$B2, dataAdd$E0  ),  msg = "Testing the Additive errStruc and betNums" )
+  checkTrue( identical( dataNone$ED50 + dataNone$B1, dataAdd$ED50),  msg = "Testing the Additive errStruc and betNums")
    
   dataNone <- createExternalParameters( 20, names = "E0,ED50,EMAX", dataId="ID",
     file = testParamFile, workingPath = parameters.datapath, 
-    errStruc = "n", betNames = "B1,B2", betNums = "1,3", seed = 2 )
+    errStruc = "N", betNames = "B1,B2", betNums = "1,3", seed = 2 )
   dataAdd  <- createExternalParameters( 20, names = "E0,ED50,EMAX", dataId="ID",
     file = testParamFile, workingPath = parameters.datapath, 
-    errStruc = "a", betNames = "B1,B2", betNums = "1,3", seed = 2 )
+    errStruc = "A", betNames = "B1,B2", betNums = "1,3", seed = 2 )
+  dataLogNorm <- createExternalParameters( 20, names = "E0,ED50,EMAX", dataId="ID",
+		file = testParamFile, workingPath = parameters.datapath, 
+		errStruc = "L", betNames = "B1,B2", betNums = "1,3", seed = 2 )
   dataProp <- createExternalParameters( 20, names = "E0,ED50,EMAX", dataId="ID",
     file = testParamFile, workingPath = parameters.datapath, 
-    errStruc = "p", betNames = "B1,B2", betNums = "1,3", seed = 2 )
-  checkTrue( identical( dataNone$E0   + dataNone$B1, dataAdd$E0  ), 
-    msg = "Testing the Additive errStruc and betNums" )
-  checkTrue( identical( dataNone$ED50, dataAdd$ED50), 
-    msg = "Testing the Additive errStruc and betNums")
-  checkTrue( identical( dataNone$EMAX + dataNone$B2, dataAdd$EMAX), 
-    msg = "Testing the Additive errStruc and betNums")
-  checkTrue( identical( exp(dataNone$E0  + dataNone$B1), dataProp$E0  ), 
-    msg = "Testing the Additive errStruc and betNums" )
-  checkTrue( identical( dataNone$ED50, dataProp$ED50), 
-    msg = "Testing the Additive errStruc and betNums, variable without between should not be exponentiated when errStruc is prop")
-  checkTrue( identical( exp(dataNone$EMAX + dataNone$B2), dataProp$EMAX), 
-    msg = "Testing the Additive errStruc and betNums")
-    
+    errStruc = "P", betNames = "B1,B2", betNums = "1,3", seed = 2 )
+
+  checkTrue( identical( dataNone$E0   + dataNone$B1, dataAdd$E0  ),  msg = "Testing the Additive errStruc and betNums" )
+  checkTrue( identical( dataNone$ED50, dataAdd$ED50),  msg = "Testing the Additive errStruc and betNums")
+  checkTrue( identical( dataNone$EMAX + dataNone$B2, dataAdd$EMAX),  msg = "Testing the Additive errStruc and betNums")
+  checkTrue( identical( dataNone$E0 * exp(dataNone$B1), dataLogNorm$E0  ),  msg = "Testing the Log-Normal errStruc and betNums" )
+  checkTrue( identical( dataNone$ED50, dataLogNorm$ED50),  msg = "Testing the Log-Normal errStruc and betNums, variable without between should not be exponentiated when errStruc is prop")
+  checkTrue( identical( dataNone$EMAX * exp(dataNone$B2), dataLogNorm$EMAX),  msg = "Testing the Log-Normal errStruc and betNums")
+  checkTrue( identical( dataNone$E0 * (1 + dataNone$B1), dataProp$E0  ),  msg = "Testing the Proportional errStruc and betNums" )
+  checkTrue( identical( dataNone$ED50, dataProp$ED50),  msg = "Testing the Proportional errStruc and betNums, variable without between should not be exponentiated when errStruc is prop")
+  checkTrue( identical( dataNone$EMAX * (1 + dataNone$B2), dataProp$EMAX),  msg = "Testing the Proportional errStruc and betNums")
     
    # testing the refCol settings
   checkException( createExternalParameters( 20, names = "E0,ED50,EMAX", dataId="ID",
@@ -183,22 +198,16 @@ test.data.param.ext <- function(){
       msg = "test that the subset is applied correctly with multiple subsets") 
    checkTrue( all( subData$B1 >= 1 & subData$B1 <= 2  ), 
       msg = "test that the subset is applied correctly with two comparators") 
-      
-      
-   # suffix
-   checkException( createExternalParameters( 20, names = "E0,ED50,EMAX", dataId="ID",
-      file = testParamFile, workingPath = parameters.datapath, 
-      suffix = c("gre", "frw") ) , 
-      msg = "length of suffix")
+
       
    # seed
   data1  <- createExternalParameters( 20, names = "E0,ED50,EMAX", dataId="ID",
     file = testParamFile, workingPath = parameters.datapath, 
-    errStruc = "a", betNames = "B1,B2", betNums = "1,3", seed = 81 )
+    errStruc = "A", betNames = "B1,B2", betNums = "1,3", seed = 81 )
   rnorm(2100 ) + runif(2)
   data2  <- createExternalParameters( 20, names = "E0,ED50,EMAX", dataId="ID",
     file = testParamFile, workingPath = parameters.datapath, 
-    errStruc = "a", betNames = "B1,B2", betNums = "1,3", seed = 81 )
+    errStruc = "A", betNames = "B1,B2", betNums = "1,3", seed = 81 )
   checkEquals( data1, data2 )
   
 }
@@ -269,72 +278,71 @@ test.data.param.norm <- function(){
   checkException( createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "0,0,0", covariance = "1", betMean = "0", 
       betNames = "X", betCov = "1", range = "X" ) , 
-    msg = "wrong range code, not enough comparators")
-   
-  checkException( createNormalParameters( 50, names = "X,Y,Z" , 
-      mean = "0,0,0", covariance = "1", betMean = "0", 
-      betNames = "X", betCov = "1", betRange = "X" ) , 
-    msg = "wrong betrange code, not enough comparators")
-   
-  checkException( createNormalParameters( 50, names = "X,Y,Z" , 
-      mean = "0,0,0", covariance = "1", betMean = "0", 
-      betNames = "X", betCov = "1", betRange = "1<X<Y<3" ) , 
-    msg = "wrong betrange code, too much comparators")
-    
+    msg = "wrong range code, not enough comparators")    
     
   dataNone <- createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "0,0,0", covariance = "1", betNames = "X,Y,Z", 
-      betCov = "1", betMean = "0,0,0", errStruc = "n", seed = 99 )
+      betCov = "1", betMean = "0,0,0", errStruc = "N", seed = 99 )
   dataAdd  <- createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "0,0,0", covariance = "1", betNames = "X,Y,Z", 
-      betCov = "1", betMean = "0,0,0", errStruc = "a", seed = 99 )
-  dataProp <- createNormalParameters( 50, names = "X,Y,Z" , 
+      betCov = "1", betMean = "0,0,0", errStruc = "A", seed = 99 )
+  dataLogNorm <- createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "0,0,0", covariance = "1", betNames = "X,Y,Z", 
-      betCov = "1", betMean = "0,0,0", errStruc = "p", seed = 99 )
+      betCov = "1", betMean = "0,0,0", errStruc = "L", seed = 99 )
       
   errStrucDiff <- round(dataAdd [,c("X", "Y", "Z") ] -  (dataNone[,c("X", "Y", "Z") ] + dataNone[, paste( c("X", "Y", "Z") , ".Between", sep = "") ]), 2) 
   checkTrue( all(unlist(errStrucDiff == 0)) ,  msg = "checking the errStruc" )
-  checkTrue( all( dataProp[,c("X", "Y", "Z") ] -  
-    exp( dataNone[,c("X", "Y", "Z") ] + dataNone[,paste( c("X", "Y", "Z") , ".Between", sep ="") ] == 0)  )   , 
-    msg = "checking the errStruc with None and Prop")
-    
-  dataNone <- createNormalParameters( 50, names = "X,Y,Z" , 
-      mean = "0,50,100", covariance = "1", betNames = "X,Y", 
-      betCov = "1", betMean = "0,0", errStruc = "n", seed = 99, digits = 10 )
-  dataAdd  <- createNormalParameters( 50, names = "X,Y,Z" , 
-      mean = "0,50,100", covariance = "1", betNames = "X,Y", 
-      betCov = "1", betMean = "0,0", errStruc = "a", seed = 99, digits = 10  )
-  dataProp <- createNormalParameters( 50, names = "X,Y,Z" , 
-      mean = "0,50,100", covariance = "1", betNames = "X,Y", 
-      betCov = "1", betMean = "0,0", errStruc = "p", seed = 99, digits = 10  )
-  .roundIt <- MSToolkit:::.roundIt
-  checkTrue( identical( .roundIt(dataAdd [,c("X", "Y") ], 5), .roundIt(dataNone[,c("X", "Y") ] + dataNone[, paste( c("X", "Y"),  ".Between", sep = "") ], 5)  )  , 
-    msg = "check the errStruc, not all between, None and Add" )
-  checkTrue( all(dataProp[,c("X", "Y") ] -  exp( dataNone[,c("X", "Y") ] + dataNone[,paste( c("X", "Y") , ".Between", sep = "") ]  ==0))   , 
-    msg = "check the errStruc, not all between, None and Prop")
-  checkTrue( identical( dataAdd$Z , dataNone$Z  )  , 
-    msg = "check the errStruc, not between, None and Add" )
-  checkTrue( identical( dataProp$Z, dataNone$Z  ) , 
-    msg = "check the errStruc, not between, None and Prop")  
-  
+  checkTrue( all( dataLogNorm[,c("X", "Y", "Z") ] -  
+		dataNone[,c("X", "Y", "Z") ] * exp( dataNone[,paste( c("X", "Y", "Z") , ".Between", sep ="") ] == 0)  )   , 
+    msg = "checking the errStruc with None and Log Normal")
+
+dataNone <- createNormalParameters( 50, names = "X,Y,Z" , 
+		mean = "0,50,100", covariance = "1", betNames = "X,Y", 
+		betCov = "1", betMean = "0,0", errStruc = "None", seed = 99, digits = 10 )
+dataNone$Z.Between <- rep(0, nrow(dataNone))
+dataAdd  <- createNormalParameters( 50, names = "X,Y,Z" , 
+		mean = "0,50,100", covariance = "1", betNames = "X,Y", 
+		betCov = "1", betMean = "0,0", errStruc = "Add", seed = 99, digits = 10  )
+dataLogNorm <- createNormalParameters( 50, names = "X,Y,Z" , 
+		mean = "0,50,100", covariance = "1", betNames = "X,Y", 
+		betCov = "1", betMean = "0,0", errStruc = "Log", seed = 99, digits = 10  )
+.roundIt <- MSToolkit:::.roundIt
+
+checkTrue( identical( .roundIt(dataAdd [,c("X", "Y") ], 5), .roundIt(dataNone[,c("X", "Y") ] + dataNone[, paste( c("X", "Y"),  ".Between", sep = "") ], 5)  )  , 
+		msg = "check the errStruc, not all between, None and Add" )
+#checkTrue( all( .roundIt(dataLogNorm[,c("Z", "Y") ] - (dataNone[,c("Z", "Y") ] * exp( dataNone[,paste( c("Z", "Y"), ".Between",sep ="") ])), 2) == 0 ) , 
+#		msg = "check the errStruc, not all between, None and Prop, different order")
+v1 <- dataLogNorm[,c("Z", "Y") ]
+v2 <- dataNone[,c("Z", "Y") ] * exp( dataNone[,paste( c("Z", "Y"), ".Between",sep ="") ])
+checkEqualsNumeric(v1, v2, tolerance = 0.1, msg = "\ncheck the errStruc, not all between, None and Prop, different order(1)")
+
+checkTrue( identical( dataAdd$Z , dataNone$Z  )  , msg = "check the errStruc, not between, None and Add" )
+checkTrue( identical( dataLogNorm$Z, dataNone$Z  ) , msg = "check the errStruc, not between, None and Prop")  
+
   dataNone <- createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "0,50,100", covariance = "1", betNames = "Z,Y", 
-      betCov = "1", betMean = "0,0", errStruc = "n", seed = 99, digits = 5 )
+      betCov = "1", betMean = "0,0", errStruc = "N", seed = 99, digits = 5 )
   dataAdd  <- createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "0,50,100", covariance = "1", betNames = "Z,Y", 
-      betCov = "1", betMean = "0,0", errStruc = "a", seed = 99, digits = 5 )
-  dataProp <- createNormalParameters( 50, names = "X,Y,Z" , 
+      betCov = "1", betMean = "0,0", errStruc = "A", seed = 99, digits = 5 )
+  dataLogNorm <- createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "0,50,100", covariance = "1", betNames = "Z,Y", 
-      betCov = "1", betMean = "0,0", errStruc = "p", seed = 99, digits = 5 )
+      betCov = "1", betMean = "0,0", errStruc = "L", seed = 99, digits = 5 )
+
   checkTrue( all( .roundIt(dataAdd [,c("Z", "Y") ]- (dataNone[,c("Z", "Y") ] + dataNone[,paste( c("Z", "Y"), ".Between",sep = "") ]), 3)  ==0) , 
     msg = "check the errStruc, not all between, None and Prop, different order")
-  checkTrue( all( dataProp[,c("Z", "Y") ]- exp( dataNone[,c("Z", "Y") ] + dataNone[,paste( c("Z", "Y"), ".Between",sep ="") ] ==0 )) , 
-    msg = "check the errStruc, not all between, None and Prop, different order")
-  checkTrue( all( dataAdd$X - dataNone$X  ==0) , 
+
+#checkTrue( all( .roundIt(dataLogNorm[,c("Z", "Y") ] - (dataNone[,c("Z", "Y") ] * exp( dataNone[,paste( c("Z", "Y"), ".Between",sep ="") ])), 2) == 0 ) , 
+#		msg = "check the errStruc, not all between, None and Prop, different order")
+v1 <- dataLogNorm[,c("Z", "Y") ]
+v2 <- dataNone[,c("Z", "Y") ] * exp( dataNone[,paste( c("Z", "Y"), ".Between",sep ="") ])
+checkEqualsNumeric(v1, v2, tolerance = 0.1, msg = "\ncheck the errStruc, not all between, None and Prop, different order(2)")
+
+checkTrue( all( dataAdd$X - dataNone$X  ==0) , 
     msg = "check the errStruc, not between, None and Prop, different order")
-  checkTrue( all( dataProp$X- dataNone$X ==0  ) , 
+  checkTrue( all( dataLogNorm$X - dataNone$X ==0  ) , 
     msg = "check the errStruc, not between, None and Prop, different order")
-    
+
   # check the outputs
   dataFixed <- createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "0,50,100", covariance = "1" )
@@ -366,20 +374,20 @@ test.data.param.wrap <- function(){
     
   d1  <- createNormalParameters( 50, names = "X,Y,Z" , 
     mean = "0,0,0", covariance = "1", betNames = "X,Y,Z", 
-    betCov = "1", betMean = "0,0,0", errStruc = "a", seed = 99 )
+    betCov = "1", betMean = "0,0,0", errStruc = "A", seed = 99 )
   d2 <-  createParameters( 50, genNames = "X,Y,Z" , 
     genFixedMean = "0,0,0", genFixedCov = "1", genBetweenNames = "X,Y,Z", 
-    genBetweenCov = "1", genBetweenMean = "0,0,0", genErrStruc = "a", seed = 99 ) 
+    genBetweenCov = "1", genBetweenMean = "0,0,0", genErrStruc = "A", seed = 99 ) 
   checkTrue( identical( d1, d2 ), 
     msg = "only normal" )  
     
   
   d1  <- createExternalParameters( 20, names = "E0,ED50,EMAX", 
     file = testParamFile, workingPath = parameters.datapath, dataId = "ID",
-    errStruc = "a", betNames = "B1,B2", betNums = "1,3", seed = 81 )
+    errStruc = "A", betNames = "B1,B2", betNums = "1,3", seed = 81 )
   d2  <- createParameters( 20, extNames = "E0,ED50,EMAX", extDataId="ID", 
     extFile = testParamFile, workingPath = parameters.datapath, 
-    extErrStruc = "a", extBetween = "B1,B2", extBetweenNums = "1,3", 
+    extErrStruc = "A", extBetween = "B1,B2", extBetweenNums = "1,3", 
     seed = 81 )
   checkTrue( identical( d1, d2 ), 
      msg = "only external" )  
@@ -388,17 +396,17 @@ test.data.param.wrap <- function(){
      
   dNor  <- createNormalParameters( 50, names = "X,Y,Z" , 
     mean = "0,0,0", covariance = "1", betNames = "X,Y,Z", 
-    betCov = "1", betMean = "0,0,0", errStruc = "a", seed = 81 )
+    betCov = "1", betMean = "0,0,0", errStruc = "A", seed = 81 )
   dExt  <- createExternalParameters( 50, names = "E0,ED50,EMAX",  dataId="ID",
     file = testParamFile, workingPath = parameters.datapath, 
-    errStruc = "a", betNames = "B1,B2", betNums = "1,3", seed = 81 )
+    errStruc = "A", betNames = "B1,B2", betNums = "1,3", seed = 81 )
   dAll  <- createParameters( 50, extNames = "E0,ED50,EMAX", 
     extFile = testParamFile, workingPath = parameters.datapath, 
-    extErrStruc = "a", extBetween = "B1,B2", extBetweenNums = "1,3", extDataId="ID",
+    extErrStruc = "A", extBetween = "B1,B2", extBetweenNums = "1,3", extDataId="ID",
     seed = 81, 
     genNames = "X,Y,Z", genFixedMean = "0,0,0", genFixedCov = "1", 
     genBetweenNames = "X,Y,Z", 
-    genBetweenCov = "1", genBetweenMean = "0,0,0", genErrStruc = "a" )
+    genBetweenCov = "1", genBetweenMean = "0,0,0", genErrStruc = "A" )
   checkTrue( identical( dNor[, c("SUBJ", "X", "Y", "Z") ] , dAll[, c("SUBJ", "X", "Y", "Z")] ) , 
     msg = "all + nor")   
   checkTrue( identical( dExt[,c("SUBJ", "E0", "ED50", "EMAX")], dAll[, c("SUBJ", "E0", "ED50", "EMAX")] ) , 
@@ -407,20 +415,20 @@ test.data.param.wrap <- function(){
     
   dNor  <- createNormalParameters( 50, names = "X,Y,Z" , 
     mean = "0,0,0", covariance = "1", betNames = "X,Y,Z", 
-    betCov = "1", betMean = "0,0,0", errStruc = "a", seed = 81, 
-    betRange = "Y < 3" )    
+    betCov = "1", betMean = "0,0,0", errStruc = "A", seed = 81, 
+    range = "Y < 3" )    
   dExt  <- createExternalParameters( 50, names = "E0,ED50,EMAX", 
     file = testParamFile, workingPath = parameters.datapath, dataId="ID",
-    errStruc = "a", betNames = "B1,B2", betNums = "1,3", seed = 81, 
+    errStruc = "A", betNames = "B1,B2", betNums = "1,3", seed = 81, 
     )
   dAll  <- createParameters( 50, extNames = "E0,ED50,EMAX", 
     extFile = testParamFile, workingPath = parameters.datapath, 
-    extErrStruc = "a", extBetween = "B1,B2", extBetweenNums = "1,3",  extDataId="ID",
+    extErrStruc = "A", extBetween = "B1,B2", extBetweenNums = "1,3",  extDataId="ID",
     seed = 81, 
     genNames = "X,Y,Z", genFixedMean = "0,0,0", genFixedCov = "1", 
     genBetweenNames = "X,Y,Z", 
-    genBetweenCov = "1", genBetweenMean = "0,0,0", genErrStruc = "a", 
-    genBetweenRange = "Y < 3")
+    genBetweenCov = "1", genBetweenMean = "0,0,0", genErrStruc = "A", 
+    genRange = "Y < 3")
  
   checkTrue( identical( dNor[, c("SUBJ", "X", "Y", "Z") ] , dAll[, c("SUBJ", "X", "Y", "Z")] ) , 
     msg = "all + nor")   
@@ -431,32 +439,26 @@ test.data.param.wrap <- function(){
      
 }
 
-test.parameter.sf3 <- function(){
-  
-  
-  checkException( createNormalParameters( 50, names = "X,Y,Z" , 
+test.parameter.sf3 <- function() {
+
+	checkException( createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "100,100,100", covariance = "1", betNames = "X,Y", 
-      betCov = "1", betMean = "0,0", errStruc = "n", digits = -1), 
+      betCov = "1", betMean = "0,0", errStruc = "N", digits = -1), 
     msg = "digits should be positive")
-  checkException( dataNone <- createNormalParameters( 50, names = "X,Y,Z" , 
-      mean = "100,100,100", covariance = "1", betNames = "X,Y", 
-      betCov = "1", betMean = "0,0", errStruc = "n", digits = "1,2" ), 
-    msg = "digits must be of good length")
-    
   
   dataNone <- createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "100,100,100", covariance = "1", betNames = "X,Y", 
-      betCov = "1", betMean = "0,0", errStruc = "n", digits = "2" )        
+      betCov = "1", betMean = "0,0", errStruc = "N", digits = "2" )        
   dataAdd  <- createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "100,100,100", covariance = "1", betNames = "X,Y", 
-      betCov = "1", betMean = "0,0", errStruc = "a", digits = "2")
-  dataProp <- createNormalParameters( 50, names = "X,Y,Z" , 
+      betCov = "1", betMean = "0,0", errStruc = "A", digits = "2")
+  dataLogNorm <- createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "100,100,100", covariance = "1", betNames = "X,Y", 
-      betCov = "1", betMean = "0,0", errStruc = "p", digits = "2")
+      betCov = "1", betMean = "0,0", errStruc = "L", digits = "2")
   
   checkEquals( dataAdd[, c("X", "Y", "Z")], round(dataAdd[, c("X", "Y", "Z")],2), 
     msg  = "check the atomic digits (add)" )
-  checkEquals( dataProp[, c("X", "Y", "Z")], round(dataProp[, c("X", "Y", "Z")],2), 
+  checkEquals( dataLogNorm[, c("X", "Y", "Z")], round(dataLogNorm[, c("X", "Y", "Z")],2), 
     msg  = "check the atomic digits (prop)" )
   checkEquals( dataNone[, c("X", "Y", "Z", "X.Between", "Y.Between")], 
     round(dataNone[, c("X", "Y", "Z", "X.Between", "Y.Between")],2), 
@@ -465,20 +467,20 @@ test.parameter.sf3 <- function(){
 
   dataNone <- createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "100,100,100", covariance = "1", betNames = "X,Y", 
-      betCov = "1", betMean = "0,0", errStruc = "n", digits = "2,3,2" )        
+      betCov = "1", betMean = "0,0", errStruc = "N", digits = "2,3,2" )        
   dataAdd  <- createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "100,100,100", covariance = "1", betNames = "X,Y", 
-      betCov = "1", betMean = "0,0", errStruc = "a", digits = "2,3,2")
-  dataProp <- createNormalParameters( 50, names = "X,Y,Z" , 
+      betCov = "1", betMean = "0,0", errStruc = "A", digits = "2,3,2")
+  dataLogNorm <- createNormalParameters( 50, names = "X,Y,Z" , 
       mean = "100,100,100", covariance = "1", betNames = "X,Y", 
-      betCov = "1", betMean = "0,0", errStruc = "p", digits = "2,3,2")
+      betCov = "1", betMean = "0,0", errStruc = "L", digits = "2,3,2")
   checkEquals( dataAdd$X, round(dataAdd$X,2),  msg  = "check the vector digits (add,X)" )
   checkEquals( dataAdd$Y, round(dataAdd$Y,3),  msg  = "check the vector digits (add,Y)" )
   checkEquals( dataAdd$Z, round(dataAdd$Z,2),  msg  = "check the vector digits (add,Y)" )
 
-  checkEquals( dataProp$X, round(dataProp$X,2), msg  = "check the vector digits (Prop,X)" )
-  checkEquals( dataProp$Y, round(dataProp$Y,3), msg  = "check the vector digits (Prop,Y)" )
-  checkEquals( dataProp$Z, round(dataProp$Z,2), msg  = "check the vector digits (Prop,Y)" )
+  checkEquals( dataLogNorm$X, round(dataLogNorm$X,2), msg  = "check the vector digits (Prop,X)" )
+  checkEquals( dataLogNorm$Y, round(dataLogNorm$Y,3), msg  = "check the vector digits (Prop,Y)" )
+  checkEquals( dataLogNorm$Z, round(dataLogNorm$Z,2), msg  = "check the vector digits (Prop,Y)" )
     
   checkEquals( dataNone$X,         round(dataNone$X,2),         msg  = "check the vector digits (None,X)" )
   checkEquals( dataNone$Y,         round(dataNone$Y,3),         msg  = "check the vector digits (None,Y)" )
@@ -495,13 +497,7 @@ test.parameter.sf8 <- function(){
   # checking betCov = 0 by default
   dataNone <- createNormalParameters( 50, names = "X,Y,Z" ,
     mean = "0,50,100",  betNames = "X,Y", covariance = "1", 
-    betMean = "0,0", errStruc = "n", seed = 99 )
-  dataAdd  <- createNormalParameters( 50, names = "X,Y,Z" , 
-    mean = "0,50,100", covariance = "1", betNames = "X,Y", 
-    betMean = "0,0", errStruc = "a", seed = 99 )
-  dataProp <- createNormalParameters( 50, names = "X,Y,Z" , 
-    mean = "0,50,100", covariance = "1", betNames = "X,Y", 
-    betMean = "0,0", errStruc = "p", seed = 99 )
+    betMean = "0,0", errStruc = "N", seed = 99 )
 
   checkTrue( all( dataNone[,c("X.Between", "Y.Between")]  == 0), 
     msg = "checking 0 covariance by default for between effects")
@@ -512,5 +508,27 @@ test.parameter.sf8 <- function(){
     
 }
 
-
-
+test.parameter.rangeExclude <- function(){
+	
+	# checking betCov = 0 by default
+	checkException(createNormalParameters( 500, names = "X,Y,Z" , 
+					mean = "0,50,100", covariance = "1", 
+					betNames = "X,Y", betCov = "1", 
+					errStruc = "A", seed = 99,
+					range = "Y < 50", maxDraws = 1, parRangeTolerance = .9 ), msg = "Bad range specified")
+	
+	checkTrue(is.data.frame(createNormalParameters( 500, names = "X,Y,Z" , 
+							mean = "0,50,100", covariance = "1", 
+							betNames = "X,Y", betCov = "1", 
+							errStruc = "A", seed = 99,
+							range = "Y < 100", maxDraws = 1, parRangeTolerance = .9 )), msg = "Good range specified")
+	
+	warnData <- suppressWarnings(createNormalParameters( 500, names = "X,Y,Z" , 
+					mean = "0,50,100", covariance = "1", 
+					betNames = "X,Y", betCov = "1", 
+					errStruc = "A", seed = 99,
+					range = "Y < 50", parRangeTolerance = .1, maxDraws = 1 ))
+	
+	checkTrue(is.data.frame(warnData) & any(warnData$PAROMIT == 1), msg = "Dataset returned with parameter omits")
+	
+}
